FloraBottomSheet class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FloraBottomSheet
Constructors
- FloraBottomSheet({Key? key, required Widget child, FloraBottomSheetOptions options = const FloraBottomSheetOptions(), Widget? leading, String? title, TextStyle? titleStyle, Widget? titleWidget, bool showInteractor = true, Widget? interactor, bool showCloseButton = true, FloraIconButtonOptions? closeIconOptions, VoidCallback? onCloseTap, Widget? closeIcon, Widget? closeIconWidget, EdgeInsets headerPadding = const EdgeInsets.symmetric(horizontal: 12, vertical: 8)})
-
const
Properties
- child → Widget
-
final
- closeIcon → Widget?
-
final
- closeIconOptions → FloraIconButtonOptions?
-
final
- closeIconWidget → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerPadding → EdgeInsets
-
final
- interactor → Widget?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leading → Widget?
-
final
- onCloseTap → VoidCallback?
-
final
- options → FloraBottomSheetOptions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCloseButton → bool
-
final
- showInteractor → bool
-
final
- title → String?
-
final
- titleStyle → TextStyle?
-
final
- titleWidget → Widget?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show<
T> (dynamic context) → Future< T?> -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited