FloraBottomSheetOptions class

Inheritance

Constructors

FloraBottomSheetOptions({double? height, double? width, EdgeInsets margin = EdgeInsets.zero, EdgeInsets? padding, Border? border, BorderRadius? borderRadius = const BorderRadius.vertical(top: Radius.circular(20)), List<BoxShadow>? boxShadow, Color? color, Duration animationDuration = const Duration(milliseconds: 200), Color? focusColor, Color? hoverColor, Color? highlightColor, MaterialStateProperty<Color?>? overlayColor, Color? splashColor, BoxShape shape = BoxShape.rectangle})
const

Properties

animationDuration Duration
finalinherited
border Border?
finalinherited
borderRadius BorderRadius?
finalinherited
boxShadow List<BoxShadow>?
finalinherited
color Color?
finalinherited
focusColor Color?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double?
finalinherited
highlightColor Color?
finalinherited
hoverColor Color?
finalinherited
margin EdgeInsets
finalinherited
overlayColor MaterialStateProperty<Color?>?
finalinherited
padding EdgeInsets?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape BoxShape
finalinherited
splashColor Color?
finalinherited
width double?
finalinherited

Methods

copyWith({Duration? animationDuration, double? height, double? width, EdgeInsets? margin, EdgeInsets? padding, Color? color, List<BoxShadow>? boxShadow, BorderRadius? borderRadius, Border? border, double? upperBound, double? lowerBound, double? tapScale, Color? focusColor, Color? hoverColor, Color? highlightColor, MaterialStateProperty<Color?>? overlayColor, Color? splashColor, BoxShape? shape}) FloraBottomSheetOptions
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited