FloraCardOptions class

Implementers

Constructors

FloraCardOptions({double? height, double? width, EdgeInsets margin = EdgeInsets.zero, EdgeInsets? padding, Color? color, List<BoxShadow>? boxShadow, BorderRadius? borderRadius, Border? border, Duration animationDuration = const Duration(milliseconds: 100), Color? focusColor, Color? hoverColor, Color? highlightColor, MaterialStateProperty<Color?>? overlayColor, Color? splashColor, BoxShape shape = BoxShape.rectangle})
const

Properties

animationDuration Duration
final
border Border?
final
borderRadius BorderRadius?
final
boxShadow List<BoxShadow>?
final
color Color?
final
focusColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
highlightColor Color?
final
hoverColor Color?
final
margin EdgeInsets
final
overlayColor MaterialStateProperty<Color?>?
final
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape BoxShape
final
splashColor Color?
final
width double?
final

Methods

copyWith({Duration? animationDuration, double? height, double? width, EdgeInsets? margin, EdgeInsets? padding, Color? color, List<BoxShadow>? boxShadow, BorderRadius? borderRadius, Border? border, Color? focusColor, Color? hoverColor, Color? highlightColor, MaterialStateProperty<Color?>? overlayColor, Color? splashColor, BoxShape? shape}) FloraCardOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited