FloraButtonOptions class
- Inheritance
-
- Object
- FloraCardOptions
- FloraAnimatedCardOptions
- FloraButtonOptions
Constructors
-
FloraButtonOptions({bool enableTapDownAnimation = true, TextStyle? titleStyle, double upperBound = 0.1, double lowerBound = 0.0, double tapScale = 0.5, double? height, double? width = double.infinity, EdgeInsets margin = EdgeInsets.zero, EdgeInsets? padding, Border? border, BorderRadius? borderRadius, List<
BoxShadow> ? boxShadow, Color? color, Duration animationDuration = const Duration(milliseconds: 200), Color? focusColor, Color? hoverColor, Color? highlightColor, MaterialStateProperty<Color?> ? overlayColor, Color? splashColor, BoxShape shape = BoxShape.rectangle}) -
const
Properties
- animationDuration → Duration
-
finalinherited
- border → Border?
-
finalinherited
- borderRadius → BorderRadius?
-
finalinherited
-
boxShadow
→ List<
BoxShadow> ? -
finalinherited
- color → Color?
-
finalinherited
- enableTapDownAnimation → bool
-
final
- focusColor → Color?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
finalinherited
- highlightColor → Color?
-
finalinherited
- hoverColor → Color?
-
finalinherited
- lowerBound → double
-
Tap start (default) transition bound
The value at which this animation is deemed to be dismissed.
finalinherited
- margin → EdgeInsets
-
finalinherited
-
overlayColor
→ MaterialStateProperty<
Color?> ? -
finalinherited
- padding → EdgeInsets?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → BoxShape
-
finalinherited
- splashColor → Color?
-
finalinherited
- tapScale → double
-
finalinherited
- titleStyle → TextStyle?
-
final
- upperBound → double
-
Tap final transition bound
The value at which this animation is deemed to be completed.
finalinherited
- width → double?
-
finalinherited
Methods
-
copyWith(
{bool? enableTapDownAnimation, TextStyle? titleStyle, Duration? animationDuration, double? height, double? width, EdgeInsets? margin, EdgeInsets? padding, Color? color, List< BoxShadow> ? boxShadow, BorderRadius? borderRadius, Border? border, double? upperBound, double? lowerBound, double? tapScale, Color? focusColor, Color? hoverColor, Color? highlightColor, MaterialStateProperty<Color?> ? overlayColor, Color? splashColor, BoxShape? shape}) → FloraButtonOptions -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited